"""KlingelnbergCycloPalloidSpiralBevelGearSetCompoundMultibodyDynamicsAnalysis"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
    _5938,
)

_KLINGELNBERG_CYCLO_PALLOID_SPIRAL_BEVEL_GEAR_SET_COMPOUND_MULTIBODY_DYNAMICS_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.MBDAnalyses.Compound",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundMultibodyDynamicsAnalysis",
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2944
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7941,
        _7944,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses import _5795
    from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
        _5870,
        _5904,
        _5930,
        _5942,
        _5943,
        _5951,
        _5970,
    )
    from mastapy._private.system_model.part_model.gears import _2823

    Self = TypeVar(
        "Self",
        bound="KlingelnbergCycloPalloidSpiralBevelGearSetCompoundMultibodyDynamicsAnalysis",
    )
    CastSelf = TypeVar(
        "CastSelf",
        bound="KlingelnbergCycloPalloidSpiralBevelGearSetCompoundMultibodyDynamicsAnalysis._Cast_KlingelnbergCycloPalloidSpiralBevelGearSetCompoundMultibodyDynamicsAnalysis",
    )


__docformat__ = "restructuredtext en"
__all__ = (
    "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundMultibodyDynamicsAnalysis",
)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_KlingelnbergCycloPalloidSpiralBevelGearSetCompoundMultibodyDynamicsAnalysis:
    """Special nested class for casting KlingelnbergCycloPalloidSpiralBevelGearSetCompoundMultibodyDynamicsAnalysis to subclasses."""

    __parent__: (
        "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundMultibodyDynamicsAnalysis"
    )

    @property
    def klingelnberg_cyclo_palloid_conical_gear_set_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> (
        "_5938.KlingelnbergCycloPalloidConicalGearSetCompoundMultibodyDynamicsAnalysis"
    ):
        return self.__parent__._cast(
            _5938.KlingelnbergCycloPalloidConicalGearSetCompoundMultibodyDynamicsAnalysis
        )

    @property
    def conical_gear_set_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5904.ConicalGearSetCompoundMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
            _5904,
        )

        return self.__parent__._cast(
            _5904.ConicalGearSetCompoundMultibodyDynamicsAnalysis
        )

    @property
    def gear_set_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5930.GearSetCompoundMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
            _5930,
        )

        return self.__parent__._cast(_5930.GearSetCompoundMultibodyDynamicsAnalysis)

    @property
    def specialised_assembly_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5970.SpecialisedAssemblyCompoundMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
            _5970,
        )

        return self.__parent__._cast(
            _5970.SpecialisedAssemblyCompoundMultibodyDynamicsAnalysis
        )

    @property
    def abstract_assembly_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5870.AbstractAssemblyCompoundMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
            _5870,
        )

        return self.__parent__._cast(
            _5870.AbstractAssemblyCompoundMultibodyDynamicsAnalysis
        )

    @property
    def part_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5951.PartCompoundMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses.compound import (
            _5951,
        )

        return self.__parent__._cast(_5951.PartCompoundMultibodyDynamicsAnalysis)

    @property
    def part_compound_analysis(self: "CastSelf") -> "_7944.PartCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7944,
        )

        return self.__parent__._cast(_7944.PartCompoundAnalysis)

    @property
    def design_entity_compound_analysis(
        self: "CastSelf",
    ) -> "_7941.DesignEntityCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7941,
        )

        return self.__parent__._cast(_7941.DesignEntityCompoundAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_set_compound_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundMultibodyDynamicsAnalysis":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class KlingelnbergCycloPalloidSpiralBevelGearSetCompoundMultibodyDynamicsAnalysis(
    _5938.KlingelnbergCycloPalloidConicalGearSetCompoundMultibodyDynamicsAnalysis
):
    """KlingelnbergCycloPalloidSpiralBevelGearSetCompoundMultibodyDynamicsAnalysis

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = (
        _KLINGELNBERG_CYCLO_PALLOID_SPIRAL_BEVEL_GEAR_SET_COMPOUND_MULTIBODY_DYNAMICS_ANALYSIS
    )

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def component_design(
        self: "Self",
    ) -> "_2823.KlingelnbergCycloPalloidSpiralBevelGearSet":
        """mastapy.system_model.part_model.gears.KlingelnbergCycloPalloidSpiralBevelGearSet

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ComponentDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def assembly_design(
        self: "Self",
    ) -> "_2823.KlingelnbergCycloPalloidSpiralBevelGearSet":
        """mastapy.system_model.part_model.gears.KlingelnbergCycloPalloidSpiralBevelGearSet

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AssemblyDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def assembly_analysis_cases_ready(
        self: "Self",
    ) -> "List[_5795.KlingelnbergCycloPalloidSpiralBevelGearSetMultibodyDynamicsAnalysis]":
        """List[mastapy.system_model.analyses_and_results.mbd_analyses.KlingelnbergCycloPalloidSpiralBevelGearSetMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AssemblyAnalysisCasesReady")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def klingelnberg_cyclo_palloid_spiral_bevel_gears_compound_multibody_dynamics_analysis(
        self: "Self",
    ) -> "List[_5942.KlingelnbergCycloPalloidSpiralBevelGearCompoundMultibodyDynamicsAnalysis]":
        """List[mastapy.system_model.analyses_and_results.mbd_analyses.compound.KlingelnbergCycloPalloidSpiralBevelGearCompoundMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped,
            "KlingelnbergCycloPalloidSpiralBevelGearsCompoundMultibodyDynamicsAnalysis",
        )

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def klingelnberg_cyclo_palloid_spiral_bevel_meshes_compound_multibody_dynamics_analysis(
        self: "Self",
    ) -> "List[_5943.KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundMultibodyDynamicsAnalysis]":
        """List[mastapy.system_model.analyses_and_results.mbd_analyses.compound.KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped,
            "KlingelnbergCycloPalloidSpiralBevelMeshesCompoundMultibodyDynamicsAnalysis",
        )

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def assembly_analysis_cases(
        self: "Self",
    ) -> "List[_5795.KlingelnbergCycloPalloidSpiralBevelGearSetMultibodyDynamicsAnalysis]":
        """List[mastapy.system_model.analyses_and_results.mbd_analyses.KlingelnbergCycloPalloidSpiralBevelGearSetMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AssemblyAnalysisCases")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(
        self: "Self",
    ) -> "_Cast_KlingelnbergCycloPalloidSpiralBevelGearSetCompoundMultibodyDynamicsAnalysis":
        """Cast to another type.

        Returns:
            _Cast_KlingelnbergCycloPalloidSpiralBevelGearSetCompoundMultibodyDynamicsAnalysis
        """
        return _Cast_KlingelnbergCycloPalloidSpiralBevelGearSetCompoundMultibodyDynamicsAnalysis(
            self
        )



"""PlasticCylindricalGearMaterial"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.list_with_selected_item import (
    promote_to_list_with_selected_item,
)
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.sentinels import ListWithSelectedItem_None
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private._internal.implicit import list_with_selected_item
from mastapy._private.gears.materials import _706

_PLASTIC_CYLINDRICAL_GEAR_MATERIAL = python_net_import(
    "SMT.MastaAPI.Gears.Materials", "PlasticCylindricalGearMaterial"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.materials import _710
    from mastapy._private.materials import _371
    from mastapy._private.utility.databases import _2063

    Self = TypeVar("Self", bound="PlasticCylindricalGearMaterial")
    CastSelf = TypeVar(
        "CastSelf",
        bound="PlasticCylindricalGearMaterial._Cast_PlasticCylindricalGearMaterial",
    )


__docformat__ = "restructuredtext en"
__all__ = ("PlasticCylindricalGearMaterial",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_PlasticCylindricalGearMaterial:
    """Special nested class for casting PlasticCylindricalGearMaterial to subclasses."""

    __parent__: "PlasticCylindricalGearMaterial"

    @property
    def cylindrical_gear_material(self: "CastSelf") -> "_706.CylindricalGearMaterial":
        return self.__parent__._cast(_706.CylindricalGearMaterial)

    @property
    def gear_material(self: "CastSelf") -> "_710.GearMaterial":
        from mastapy._private.gears.materials import _710

        return self.__parent__._cast(_710.GearMaterial)

    @property
    def material(self: "CastSelf") -> "_371.Material":
        from mastapy._private.materials import _371

        return self.__parent__._cast(_371.Material)

    @property
    def named_database_item(self: "CastSelf") -> "_2063.NamedDatabaseItem":
        from mastapy._private.utility.databases import _2063

        return self.__parent__._cast(_2063.NamedDatabaseItem)

    @property
    def plastic_cylindrical_gear_material(
        self: "CastSelf",
    ) -> "PlasticCylindricalGearMaterial":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class PlasticCylindricalGearMaterial(_706.CylindricalGearMaterial):
    """PlasticCylindricalGearMaterial

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _PLASTIC_CYLINDRICAL_GEAR_MATERIAL

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def glass_transition_temperature(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "GlassTransitionTemperature")

        if temp is None:
            return 0.0

        return temp

    @glass_transition_temperature.setter
    @exception_bridge
    @enforce_parameter_types
    def glass_transition_temperature(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "GlassTransitionTemperature",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def material_type(
        self: "Self",
    ) -> "list_with_selected_item.ListWithSelectedItem_str":
        """ListWithSelectedItem[str]"""
        temp = pythonnet_property_get(self.wrapped, "MaterialType")

        if temp is None:
            return ""

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_str",
        )(temp)

    @material_type.setter
    @exception_bridge
    @enforce_parameter_types
    def material_type(self: "Self", value: "str") -> None:
        generic_type = list_with_selected_item.ListWithSelectedItem_str.implicit_type()
        value = promote_to_list_with_selected_item(value)
        value = conversion.mp_to_pn_smt_list_with_selected_item(
            self, value, generic_type
        )
        pythonnet_property_set(self.wrapped, "MaterialType", value)

    @property
    @exception_bridge
    def melting_temperature(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "MeltingTemperature")

        if temp is None:
            return 0.0

        return temp

    @melting_temperature.setter
    @exception_bridge
    @enforce_parameter_types
    def melting_temperature(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "MeltingTemperature",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def modulus_of_elasticity(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "ModulusOfElasticity")

        if temp is None:
            return 0.0

        return temp

    @modulus_of_elasticity.setter
    @exception_bridge
    @enforce_parameter_types
    def modulus_of_elasticity(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "ModulusOfElasticity",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def n0_bending(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "N0Bending")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def n0_contact(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "N0Contact")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def permissible_temperature_for_continuous_operation(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(
            self.wrapped, "PermissibleTemperatureForContinuousOperation"
        )

        if temp is None:
            return 0.0

        return temp

    @permissible_temperature_for_continuous_operation.setter
    @exception_bridge
    @enforce_parameter_types
    def permissible_temperature_for_continuous_operation(
        self: "Self", value: "float"
    ) -> None:
        pythonnet_property_set(
            self.wrapped,
            "PermissibleTemperatureForContinuousOperation",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def permissible_temperature_for_intermittent_operation(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(
            self.wrapped, "PermissibleTemperatureForIntermittentOperation"
        )

        if temp is None:
            return 0.0

        return temp

    @permissible_temperature_for_intermittent_operation.setter
    @exception_bridge
    @enforce_parameter_types
    def permissible_temperature_for_intermittent_operation(
        self: "Self", value: "float"
    ) -> None:
        pythonnet_property_set(
            self.wrapped,
            "PermissibleTemperatureForIntermittentOperation",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def use_custom_material_for_bending(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "UseCustomMaterialForBending")

        if temp is None:
            return False

        return temp

    @use_custom_material_for_bending.setter
    @exception_bridge
    @enforce_parameter_types
    def use_custom_material_for_bending(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "UseCustomMaterialForBending",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def use_custom_material_for_contact(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "UseCustomMaterialForContact")

        if temp is None:
            return False

        return temp

    @use_custom_material_for_contact.setter
    @exception_bridge
    @enforce_parameter_types
    def use_custom_material_for_contact(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "UseCustomMaterialForContact",
            bool(value) if value is not None else False,
        )

    @property
    def cast_to(self: "Self") -> "_Cast_PlasticCylindricalGearMaterial":
        """Cast to another type.

        Returns:
            _Cast_PlasticCylindricalGearMaterial
        """
        return _Cast_PlasticCylindricalGearMaterial(self)



"""LoadedTaperRollerBearingElement"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import utility
from mastapy._private.bearings.bearing_results.rolling import _2267

_LOADED_TAPER_ROLLER_BEARING_ELEMENT = python_net_import(
    "SMT.MastaAPI.Bearings.BearingResults.Rolling", "LoadedTaperRollerBearingElement"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.bearings.bearing_results.rolling import _2257, _2272

    Self = TypeVar("Self", bound="LoadedTaperRollerBearingElement")
    CastSelf = TypeVar(
        "CastSelf",
        bound="LoadedTaperRollerBearingElement._Cast_LoadedTaperRollerBearingElement",
    )


__docformat__ = "restructuredtext en"
__all__ = ("LoadedTaperRollerBearingElement",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_LoadedTaperRollerBearingElement:
    """Special nested class for casting LoadedTaperRollerBearingElement to subclasses."""

    __parent__: "LoadedTaperRollerBearingElement"

    @property
    def loaded_non_barrel_roller_bearing_element(
        self: "CastSelf",
    ) -> "_2267.LoadedNonBarrelRollerBearingElement":
        return self.__parent__._cast(_2267.LoadedNonBarrelRollerBearingElement)

    @property
    def loaded_roller_bearing_element(
        self: "CastSelf",
    ) -> "_2272.LoadedRollerBearingElement":
        from mastapy._private.bearings.bearing_results.rolling import _2272

        return self.__parent__._cast(_2272.LoadedRollerBearingElement)

    @property
    def loaded_element(self: "CastSelf") -> "_2257.LoadedElement":
        from mastapy._private.bearings.bearing_results.rolling import _2257

        return self.__parent__._cast(_2257.LoadedElement)

    @property
    def loaded_taper_roller_bearing_element(
        self: "CastSelf",
    ) -> "LoadedTaperRollerBearingElement":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class LoadedTaperRollerBearingElement(_2267.LoadedNonBarrelRollerBearingElement):
    """LoadedTaperRollerBearingElement

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _LOADED_TAPER_ROLLER_BEARING_ELEMENT

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def height_of_rib_roller_contact_above_race_inner_left(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "HeightOfRibRollerContactAboveRaceInnerLeft"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def height_of_rib_roller_contact_above_race_inner_right(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "HeightOfRibRollerContactAboveRaceInnerRight"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def height_of_rib_roller_contact_above_race_outer_left(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "HeightOfRibRollerContactAboveRaceOuterLeft"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def height_of_rib_roller_contact_above_race_outer_right(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "HeightOfRibRollerContactAboveRaceOuterRight"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def maximum_rib_stress_inner_left(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "MaximumRibStressInnerLeft")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def maximum_rib_stress_inner_right(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "MaximumRibStressInnerRight")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def maximum_rib_stress_outer_left(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "MaximumRibStressOuterLeft")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def maximum_rib_stress_outer_right(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "MaximumRibStressOuterRight")

        if temp is None:
            return 0.0

        return temp

    @property
    def cast_to(self: "Self") -> "_Cast_LoadedTaperRollerBearingElement":
        """Cast to another type.

        Returns:
            _Cast_LoadedTaperRollerBearingElement
        """
        return _Cast_LoadedTaperRollerBearingElement(self)



"""FaceGearMeshParametricStudyTool"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
    _4679,
)

_FACE_GEAR_MESH_PARAMETRIC_STUDY_TOOL = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.ParametricStudyTools",
    "FaceGearMeshParametricStudyTool",
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2942, _2944, _2946
    from mastapy._private.system_model.analyses_and_results.analysis_cases import _7936
    from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
        _4649,
        _4686,
    )
    from mastapy._private.system_model.analyses_and_results.static_loads import _7808
    from mastapy._private.system_model.analyses_and_results.system_deflections import (
        _3047,
    )
    from mastapy._private.system_model.connections_and_sockets.gears import _2571

    Self = TypeVar("Self", bound="FaceGearMeshParametricStudyTool")
    CastSelf = TypeVar(
        "CastSelf",
        bound="FaceGearMeshParametricStudyTool._Cast_FaceGearMeshParametricStudyTool",
    )


__docformat__ = "restructuredtext en"
__all__ = ("FaceGearMeshParametricStudyTool",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_FaceGearMeshParametricStudyTool:
    """Special nested class for casting FaceGearMeshParametricStudyTool to subclasses."""

    __parent__: "FaceGearMeshParametricStudyTool"

    @property
    def gear_mesh_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4679.GearMeshParametricStudyTool":
        return self.__parent__._cast(_4679.GearMeshParametricStudyTool)

    @property
    def inter_mountable_component_connection_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4686.InterMountableComponentConnectionParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4686,
        )

        return self.__parent__._cast(
            _4686.InterMountableComponentConnectionParametricStudyTool
        )

    @property
    def connection_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4649.ConnectionParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4649,
        )

        return self.__parent__._cast(_4649.ConnectionParametricStudyTool)

    @property
    def connection_analysis_case(self: "CastSelf") -> "_7936.ConnectionAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7936,
        )

        return self.__parent__._cast(_7936.ConnectionAnalysisCase)

    @property
    def connection_analysis(self: "CastSelf") -> "_2942.ConnectionAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2942

        return self.__parent__._cast(_2942.ConnectionAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2946.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2946

        return self.__parent__._cast(_2946.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def face_gear_mesh_parametric_study_tool(
        self: "CastSelf",
    ) -> "FaceGearMeshParametricStudyTool":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class FaceGearMeshParametricStudyTool(_4679.GearMeshParametricStudyTool):
    """FaceGearMeshParametricStudyTool

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _FACE_GEAR_MESH_PARAMETRIC_STUDY_TOOL

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def connection_design(self: "Self") -> "_2571.FaceGearMesh":
        """mastapy.system_model.connections_and_sockets.gears.FaceGearMesh

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ConnectionDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def connection_load_case(self: "Self") -> "_7808.FaceGearMeshLoadCase":
        """mastapy.system_model.analyses_and_results.static_loads.FaceGearMeshLoadCase

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ConnectionLoadCase")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def connection_system_deflection_results(
        self: "Self",
    ) -> "List[_3047.FaceGearMeshSystemDeflection]":
        """List[mastapy.system_model.analyses_and_results.system_deflections.FaceGearMeshSystemDeflection]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ConnectionSystemDeflectionResults")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_FaceGearMeshParametricStudyTool":
        """Cast to another type.

        Returns:
            _Cast_FaceGearMeshParametricStudyTool
        """
        return _Cast_FaceGearMeshParametricStudyTool(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7584 import (
        AbstractAssemblyCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7585 import (
        AbstractShaftCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7586 import (
        AbstractShaftOrHousingCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7587 import (
        AbstractShaftToMountableComponentConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7588 import (
        AGMAGleasonConicalGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7589 import (
        AGMAGleasonConicalGearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7590 import (
        AGMAGleasonConicalGearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7591 import (
        AssemblyCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7592 import (
        BearingCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7593 import (
        BeltConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7594 import (
        BeltDriveCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7595 import (
        BevelDifferentialGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7596 import (
        BevelDifferentialGearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7597 import (
        BevelDifferentialGearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7598 import (
        BevelDifferentialPlanetGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7599 import (
        BevelDifferentialSunGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7600 import (
        BevelGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7601 import (
        BevelGearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7602 import (
        BevelGearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7603 import (
        BoltCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7604 import (
        BoltedJointCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7605 import (
        ClutchCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7606 import (
        ClutchConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7607 import (
        ClutchHalfCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7608 import (
        CoaxialConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7609 import (
        ComponentCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7610 import (
        ConceptCouplingCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7611 import (
        ConceptCouplingConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7612 import (
        ConceptCouplingHalfCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7613 import (
        ConceptGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7614 import (
        ConceptGearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7615 import (
        ConceptGearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7616 import (
        ConicalGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7617 import (
        ConicalGearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7618 import (
        ConicalGearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7619 import (
        ConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7620 import (
        ConnectorCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7621 import (
        CouplingCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7622 import (
        CouplingConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7623 import (
        CouplingHalfCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7624 import (
        CVTBeltConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7625 import (
        CVTCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7626 import (
        CVTPulleyCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7627 import (
        CycloidalAssemblyCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7628 import (
        CycloidalDiscCentralBearingConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7629 import (
        CycloidalDiscCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7630 import (
        CycloidalDiscPlanetaryBearingConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7631 import (
        CylindricalGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7632 import (
        CylindricalGearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7633 import (
        CylindricalGearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7634 import (
        CylindricalPlanetGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7635 import (
        DatumCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7636 import (
        ExternalCADModelCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7637 import (
        FaceGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7638 import (
        FaceGearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7639 import (
        FaceGearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7640 import (
        FEPartCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7641 import (
        FlexiblePinAssemblyCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7642 import (
        GearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7643 import (
        GearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7644 import (
        GearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7645 import (
        GuideDxfModelCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7646 import (
        HypoidGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7647 import (
        HypoidGearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7648 import (
        HypoidGearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7649 import (
        InterMountableComponentConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7650 import (
        KlingelnbergCycloPalloidConicalGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7651 import (
        KlingelnbergCycloPalloidConicalGearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7652 import (
        KlingelnbergCycloPalloidConicalGearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7653 import (
        KlingelnbergCycloPalloidHypoidGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7654 import (
        KlingelnbergCycloPalloidHypoidGearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7655 import (
        KlingelnbergCycloPalloidHypoidGearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7656 import (
        KlingelnbergCycloPalloidSpiralBevelGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7657 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7658 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7659 import (
        MassDiscCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7660 import (
        MeasurementComponentCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7661 import (
        MicrophoneArrayCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7662 import (
        MicrophoneCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7663 import (
        MountableComponentCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7664 import (
        OilSealCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7665 import (
        PartCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7666 import (
        PartToPartShearCouplingCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7667 import (
        PartToPartShearCouplingConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7668 import (
        PartToPartShearCouplingHalfCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7669 import (
        PlanetaryConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7670 import (
        PlanetaryGearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7671 import (
        PlanetCarrierCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7672 import (
        PointLoadCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7673 import (
        PowerLoadCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7674 import (
        PulleyCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7675 import (
        RingPinsCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7676 import (
        RingPinsToDiscConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7677 import (
        RollingRingAssemblyCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7678 import (
        RollingRingCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7679 import (
        RollingRingConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7680 import (
        RootAssemblyCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7681 import (
        ShaftCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7682 import (
        ShaftHubConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7683 import (
        ShaftToMountableComponentConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7684 import (
        SpecialisedAssemblyCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7685 import (
        SpiralBevelGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7686 import (
        SpiralBevelGearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7687 import (
        SpiralBevelGearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7688 import (
        SpringDamperCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7689 import (
        SpringDamperConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7690 import (
        SpringDamperHalfCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7691 import (
        StraightBevelDiffGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7692 import (
        StraightBevelDiffGearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7693 import (
        StraightBevelDiffGearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7694 import (
        StraightBevelGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7695 import (
        StraightBevelGearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7696 import (
        StraightBevelGearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7697 import (
        StraightBevelPlanetGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7698 import (
        StraightBevelSunGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7699 import (
        SynchroniserCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7700 import (
        SynchroniserHalfCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7701 import (
        SynchroniserPartCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7702 import (
        SynchroniserSleeveCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7703 import (
        TorqueConverterCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7704 import (
        TorqueConverterConnectionCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7705 import (
        TorqueConverterPumpCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7706 import (
        TorqueConverterTurbineCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7707 import (
        UnbalancedMassCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7708 import (
        VirtualComponentCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7709 import (
        WormGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7710 import (
        WormGearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7711 import (
        WormGearSetCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7712 import (
        ZerolBevelGearCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7713 import (
        ZerolBevelGearMeshCompoundAdvancedSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections.compound._7714 import (
        ZerolBevelGearSetCompoundAdvancedSystemDeflection,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7584": [
            "AbstractAssemblyCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7585": [
            "AbstractShaftCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7586": [
            "AbstractShaftOrHousingCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7587": [
            "AbstractShaftToMountableComponentConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7588": [
            "AGMAGleasonConicalGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7589": [
            "AGMAGleasonConicalGearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7590": [
            "AGMAGleasonConicalGearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7591": [
            "AssemblyCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7592": [
            "BearingCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7593": [
            "BeltConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7594": [
            "BeltDriveCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7595": [
            "BevelDifferentialGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7596": [
            "BevelDifferentialGearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7597": [
            "BevelDifferentialGearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7598": [
            "BevelDifferentialPlanetGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7599": [
            "BevelDifferentialSunGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7600": [
            "BevelGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7601": [
            "BevelGearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7602": [
            "BevelGearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7603": [
            "BoltCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7604": [
            "BoltedJointCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7605": [
            "ClutchCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7606": [
            "ClutchConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7607": [
            "ClutchHalfCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7608": [
            "CoaxialConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7609": [
            "ComponentCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7610": [
            "ConceptCouplingCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7611": [
            "ConceptCouplingConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7612": [
            "ConceptCouplingHalfCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7613": [
            "ConceptGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7614": [
            "ConceptGearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7615": [
            "ConceptGearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7616": [
            "ConicalGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7617": [
            "ConicalGearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7618": [
            "ConicalGearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7619": [
            "ConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7620": [
            "ConnectorCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7621": [
            "CouplingCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7622": [
            "CouplingConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7623": [
            "CouplingHalfCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7624": [
            "CVTBeltConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7625": [
            "CVTCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7626": [
            "CVTPulleyCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7627": [
            "CycloidalAssemblyCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7628": [
            "CycloidalDiscCentralBearingConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7629": [
            "CycloidalDiscCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7630": [
            "CycloidalDiscPlanetaryBearingConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7631": [
            "CylindricalGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7632": [
            "CylindricalGearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7633": [
            "CylindricalGearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7634": [
            "CylindricalPlanetGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7635": [
            "DatumCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7636": [
            "ExternalCADModelCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7637": [
            "FaceGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7638": [
            "FaceGearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7639": [
            "FaceGearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7640": [
            "FEPartCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7641": [
            "FlexiblePinAssemblyCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7642": [
            "GearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7643": [
            "GearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7644": [
            "GearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7645": [
            "GuideDxfModelCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7646": [
            "HypoidGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7647": [
            "HypoidGearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7648": [
            "HypoidGearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7649": [
            "InterMountableComponentConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7650": [
            "KlingelnbergCycloPalloidConicalGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7651": [
            "KlingelnbergCycloPalloidConicalGearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7652": [
            "KlingelnbergCycloPalloidConicalGearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7653": [
            "KlingelnbergCycloPalloidHypoidGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7654": [
            "KlingelnbergCycloPalloidHypoidGearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7655": [
            "KlingelnbergCycloPalloidHypoidGearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7656": [
            "KlingelnbergCycloPalloidSpiralBevelGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7657": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7658": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7659": [
            "MassDiscCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7660": [
            "MeasurementComponentCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7661": [
            "MicrophoneArrayCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7662": [
            "MicrophoneCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7663": [
            "MountableComponentCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7664": [
            "OilSealCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7665": [
            "PartCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7666": [
            "PartToPartShearCouplingCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7667": [
            "PartToPartShearCouplingConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7668": [
            "PartToPartShearCouplingHalfCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7669": [
            "PlanetaryConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7670": [
            "PlanetaryGearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7671": [
            "PlanetCarrierCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7672": [
            "PointLoadCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7673": [
            "PowerLoadCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7674": [
            "PulleyCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7675": [
            "RingPinsCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7676": [
            "RingPinsToDiscConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7677": [
            "RollingRingAssemblyCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7678": [
            "RollingRingCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7679": [
            "RollingRingConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7680": [
            "RootAssemblyCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7681": [
            "ShaftCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7682": [
            "ShaftHubConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7683": [
            "ShaftToMountableComponentConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7684": [
            "SpecialisedAssemblyCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7685": [
            "SpiralBevelGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7686": [
            "SpiralBevelGearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7687": [
            "SpiralBevelGearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7688": [
            "SpringDamperCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7689": [
            "SpringDamperConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7690": [
            "SpringDamperHalfCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7691": [
            "StraightBevelDiffGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7692": [
            "StraightBevelDiffGearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7693": [
            "StraightBevelDiffGearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7694": [
            "StraightBevelGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7695": [
            "StraightBevelGearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7696": [
            "StraightBevelGearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7697": [
            "StraightBevelPlanetGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7698": [
            "StraightBevelSunGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7699": [
            "SynchroniserCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7700": [
            "SynchroniserHalfCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7701": [
            "SynchroniserPartCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7702": [
            "SynchroniserSleeveCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7703": [
            "TorqueConverterCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7704": [
            "TorqueConverterConnectionCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7705": [
            "TorqueConverterPumpCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7706": [
            "TorqueConverterTurbineCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7707": [
            "UnbalancedMassCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7708": [
            "VirtualComponentCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7709": [
            "WormGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7710": [
            "WormGearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7711": [
            "WormGearSetCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7712": [
            "ZerolBevelGearCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7713": [
            "ZerolBevelGearMeshCompoundAdvancedSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.advanced_system_deflections.compound._7714": [
            "ZerolBevelGearSetCompoundAdvancedSystemDeflection"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyCompoundAdvancedSystemDeflection",
    "AbstractShaftCompoundAdvancedSystemDeflection",
    "AbstractShaftOrHousingCompoundAdvancedSystemDeflection",
    "AbstractShaftToMountableComponentConnectionCompoundAdvancedSystemDeflection",
    "AGMAGleasonConicalGearCompoundAdvancedSystemDeflection",
    "AGMAGleasonConicalGearMeshCompoundAdvancedSystemDeflection",
    "AGMAGleasonConicalGearSetCompoundAdvancedSystemDeflection",
    "AssemblyCompoundAdvancedSystemDeflection",
    "BearingCompoundAdvancedSystemDeflection",
    "BeltConnectionCompoundAdvancedSystemDeflection",
    "BeltDriveCompoundAdvancedSystemDeflection",
    "BevelDifferentialGearCompoundAdvancedSystemDeflection",
    "BevelDifferentialGearMeshCompoundAdvancedSystemDeflection",
    "BevelDifferentialGearSetCompoundAdvancedSystemDeflection",
    "BevelDifferentialPlanetGearCompoundAdvancedSystemDeflection",
    "BevelDifferentialSunGearCompoundAdvancedSystemDeflection",
    "BevelGearCompoundAdvancedSystemDeflection",
    "BevelGearMeshCompoundAdvancedSystemDeflection",
    "BevelGearSetCompoundAdvancedSystemDeflection",
    "BoltCompoundAdvancedSystemDeflection",
    "BoltedJointCompoundAdvancedSystemDeflection",
    "ClutchCompoundAdvancedSystemDeflection",
    "ClutchConnectionCompoundAdvancedSystemDeflection",
    "ClutchHalfCompoundAdvancedSystemDeflection",
    "CoaxialConnectionCompoundAdvancedSystemDeflection",
    "ComponentCompoundAdvancedSystemDeflection",
    "ConceptCouplingCompoundAdvancedSystemDeflection",
    "ConceptCouplingConnectionCompoundAdvancedSystemDeflection",
    "ConceptCouplingHalfCompoundAdvancedSystemDeflection",
    "ConceptGearCompoundAdvancedSystemDeflection",
    "ConceptGearMeshCompoundAdvancedSystemDeflection",
    "ConceptGearSetCompoundAdvancedSystemDeflection",
    "ConicalGearCompoundAdvancedSystemDeflection",
    "ConicalGearMeshCompoundAdvancedSystemDeflection",
    "ConicalGearSetCompoundAdvancedSystemDeflection",
    "ConnectionCompoundAdvancedSystemDeflection",
    "ConnectorCompoundAdvancedSystemDeflection",
    "CouplingCompoundAdvancedSystemDeflection",
    "CouplingConnectionCompoundAdvancedSystemDeflection",
    "CouplingHalfCompoundAdvancedSystemDeflection",
    "CVTBeltConnectionCompoundAdvancedSystemDeflection",
    "CVTCompoundAdvancedSystemDeflection",
    "CVTPulleyCompoundAdvancedSystemDeflection",
    "CycloidalAssemblyCompoundAdvancedSystemDeflection",
    "CycloidalDiscCentralBearingConnectionCompoundAdvancedSystemDeflection",
    "CycloidalDiscCompoundAdvancedSystemDeflection",
    "CycloidalDiscPlanetaryBearingConnectionCompoundAdvancedSystemDeflection",
    "CylindricalGearCompoundAdvancedSystemDeflection",
    "CylindricalGearMeshCompoundAdvancedSystemDeflection",
    "CylindricalGearSetCompoundAdvancedSystemDeflection",
    "CylindricalPlanetGearCompoundAdvancedSystemDeflection",
    "DatumCompoundAdvancedSystemDeflection",
    "ExternalCADModelCompoundAdvancedSystemDeflection",
    "FaceGearCompoundAdvancedSystemDeflection",
    "FaceGearMeshCompoundAdvancedSystemDeflection",
    "FaceGearSetCompoundAdvancedSystemDeflection",
    "FEPartCompoundAdvancedSystemDeflection",
    "FlexiblePinAssemblyCompoundAdvancedSystemDeflection",
    "GearCompoundAdvancedSystemDeflection",
    "GearMeshCompoundAdvancedSystemDeflection",
    "GearSetCompoundAdvancedSystemDeflection",
    "GuideDxfModelCompoundAdvancedSystemDeflection",
    "HypoidGearCompoundAdvancedSystemDeflection",
    "HypoidGearMeshCompoundAdvancedSystemDeflection",
    "HypoidGearSetCompoundAdvancedSystemDeflection",
    "InterMountableComponentConnectionCompoundAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidConicalGearCompoundAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidConicalGearMeshCompoundAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidConicalGearSetCompoundAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidHypoidGearCompoundAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidHypoidGearMeshCompoundAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidHypoidGearSetCompoundAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidSpiralBevelGearCompoundAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundAdvancedSystemDeflection",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundAdvancedSystemDeflection",
    "MassDiscCompoundAdvancedSystemDeflection",
    "MeasurementComponentCompoundAdvancedSystemDeflection",
    "MicrophoneArrayCompoundAdvancedSystemDeflection",
    "MicrophoneCompoundAdvancedSystemDeflection",
    "MountableComponentCompoundAdvancedSystemDeflection",
    "OilSealCompoundAdvancedSystemDeflection",
    "PartCompoundAdvancedSystemDeflection",
    "PartToPartShearCouplingCompoundAdvancedSystemDeflection",
    "PartToPartShearCouplingConnectionCompoundAdvancedSystemDeflection",
    "PartToPartShearCouplingHalfCompoundAdvancedSystemDeflection",
    "PlanetaryConnectionCompoundAdvancedSystemDeflection",
    "PlanetaryGearSetCompoundAdvancedSystemDeflection",
    "PlanetCarrierCompoundAdvancedSystemDeflection",
    "PointLoadCompoundAdvancedSystemDeflection",
    "PowerLoadCompoundAdvancedSystemDeflection",
    "PulleyCompoundAdvancedSystemDeflection",
    "RingPinsCompoundAdvancedSystemDeflection",
    "RingPinsToDiscConnectionCompoundAdvancedSystemDeflection",
    "RollingRingAssemblyCompoundAdvancedSystemDeflection",
    "RollingRingCompoundAdvancedSystemDeflection",
    "RollingRingConnectionCompoundAdvancedSystemDeflection",
    "RootAssemblyCompoundAdvancedSystemDeflection",
    "ShaftCompoundAdvancedSystemDeflection",
    "ShaftHubConnectionCompoundAdvancedSystemDeflection",
    "ShaftToMountableComponentConnectionCompoundAdvancedSystemDeflection",
    "SpecialisedAssemblyCompoundAdvancedSystemDeflection",
    "SpiralBevelGearCompoundAdvancedSystemDeflection",
    "SpiralBevelGearMeshCompoundAdvancedSystemDeflection",
    "SpiralBevelGearSetCompoundAdvancedSystemDeflection",
    "SpringDamperCompoundAdvancedSystemDeflection",
    "SpringDamperConnectionCompoundAdvancedSystemDeflection",
    "SpringDamperHalfCompoundAdvancedSystemDeflection",
    "StraightBevelDiffGearCompoundAdvancedSystemDeflection",
    "StraightBevelDiffGearMeshCompoundAdvancedSystemDeflection",
    "StraightBevelDiffGearSetCompoundAdvancedSystemDeflection",
    "StraightBevelGearCompoundAdvancedSystemDeflection",
    "StraightBevelGearMeshCompoundAdvancedSystemDeflection",
    "StraightBevelGearSetCompoundAdvancedSystemDeflection",
    "StraightBevelPlanetGearCompoundAdvancedSystemDeflection",
    "StraightBevelSunGearCompoundAdvancedSystemDeflection",
    "SynchroniserCompoundAdvancedSystemDeflection",
    "SynchroniserHalfCompoundAdvancedSystemDeflection",
    "SynchroniserPartCompoundAdvancedSystemDeflection",
    "SynchroniserSleeveCompoundAdvancedSystemDeflection",
    "TorqueConverterCompoundAdvancedSystemDeflection",
    "TorqueConverterConnectionCompoundAdvancedSystemDeflection",
    "TorqueConverterPumpCompoundAdvancedSystemDeflection",
    "TorqueConverterTurbineCompoundAdvancedSystemDeflection",
    "UnbalancedMassCompoundAdvancedSystemDeflection",
    "VirtualComponentCompoundAdvancedSystemDeflection",
    "WormGearCompoundAdvancedSystemDeflection",
    "WormGearMeshCompoundAdvancedSystemDeflection",
    "WormGearSetCompoundAdvancedSystemDeflection",
    "ZerolBevelGearCompoundAdvancedSystemDeflection",
    "ZerolBevelGearMeshCompoundAdvancedSystemDeflection",
    "ZerolBevelGearSetCompoundAdvancedSystemDeflection",
)



"""MountableComponentCompoundStabilityAnalysis"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import conversion, utility
from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
    _4234,
)

_MOUNTABLE_COMPONENT_COMPOUND_STABILITY_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.StabilityAnalyses.Compound",
    "MountableComponentCompoundStabilityAnalysis",
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2944
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7941,
        _7944,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses import (
        _4154,
    )
    from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
        _4213,
        _4217,
        _4220,
        _4223,
        _4224,
        _4225,
        _4232,
        _4237,
        _4238,
        _4241,
        _4245,
        _4248,
        _4251,
        _4256,
        _4259,
        _4262,
        _4267,
        _4271,
        _4275,
        _4278,
        _4281,
        _4284,
        _4285,
        _4289,
        _4290,
        _4293,
        _4296,
        _4297,
        _4298,
        _4299,
        _4300,
        _4303,
        _4307,
        _4310,
        _4315,
        _4316,
        _4319,
        _4322,
        _4323,
        _4325,
        _4326,
        _4327,
        _4330,
        _4331,
        _4332,
        _4333,
        _4334,
        _4337,
    )

    Self = TypeVar("Self", bound="MountableComponentCompoundStabilityAnalysis")
    CastSelf = TypeVar(
        "CastSelf",
        bound="MountableComponentCompoundStabilityAnalysis._Cast_MountableComponentCompoundStabilityAnalysis",
    )


__docformat__ = "restructuredtext en"
__all__ = ("MountableComponentCompoundStabilityAnalysis",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_MountableComponentCompoundStabilityAnalysis:
    """Special nested class for casting MountableComponentCompoundStabilityAnalysis to subclasses."""

    __parent__: "MountableComponentCompoundStabilityAnalysis"

    @property
    def component_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4234.ComponentCompoundStabilityAnalysis":
        return self.__parent__._cast(_4234.ComponentCompoundStabilityAnalysis)

    @property
    def part_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4290.PartCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4290,
        )

        return self.__parent__._cast(_4290.PartCompoundStabilityAnalysis)

    @property
    def part_compound_analysis(self: "CastSelf") -> "_7944.PartCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7944,
        )

        return self.__parent__._cast(_7944.PartCompoundAnalysis)

    @property
    def design_entity_compound_analysis(
        self: "CastSelf",
    ) -> "_7941.DesignEntityCompoundAnalysis":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7941,
        )

        return self.__parent__._cast(_7941.DesignEntityCompoundAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def agma_gleason_conical_gear_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4213.AGMAGleasonConicalGearCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4213,
        )

        return self.__parent__._cast(
            _4213.AGMAGleasonConicalGearCompoundStabilityAnalysis
        )

    @property
    def bearing_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4217.BearingCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4217,
        )

        return self.__parent__._cast(_4217.BearingCompoundStabilityAnalysis)

    @property
    def bevel_differential_gear_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4220.BevelDifferentialGearCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4220,
        )

        return self.__parent__._cast(
            _4220.BevelDifferentialGearCompoundStabilityAnalysis
        )

    @property
    def bevel_differential_planet_gear_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4223.BevelDifferentialPlanetGearCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4223,
        )

        return self.__parent__._cast(
            _4223.BevelDifferentialPlanetGearCompoundStabilityAnalysis
        )

    @property
    def bevel_differential_sun_gear_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4224.BevelDifferentialSunGearCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4224,
        )

        return self.__parent__._cast(
            _4224.BevelDifferentialSunGearCompoundStabilityAnalysis
        )

    @property
    def bevel_gear_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4225.BevelGearCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4225,
        )

        return self.__parent__._cast(_4225.BevelGearCompoundStabilityAnalysis)

    @property
    def clutch_half_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4232.ClutchHalfCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4232,
        )

        return self.__parent__._cast(_4232.ClutchHalfCompoundStabilityAnalysis)

    @property
    def concept_coupling_half_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4237.ConceptCouplingHalfCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4237,
        )

        return self.__parent__._cast(_4237.ConceptCouplingHalfCompoundStabilityAnalysis)

    @property
    def concept_gear_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4238.ConceptGearCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4238,
        )

        return self.__parent__._cast(_4238.ConceptGearCompoundStabilityAnalysis)

    @property
    def conical_gear_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4241.ConicalGearCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4241,
        )

        return self.__parent__._cast(_4241.ConicalGearCompoundStabilityAnalysis)

    @property
    def connector_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4245.ConnectorCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4245,
        )

        return self.__parent__._cast(_4245.ConnectorCompoundStabilityAnalysis)

    @property
    def coupling_half_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4248.CouplingHalfCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4248,
        )

        return self.__parent__._cast(_4248.CouplingHalfCompoundStabilityAnalysis)

    @property
    def cvt_pulley_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4251.CVTPulleyCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4251,
        )

        return self.__parent__._cast(_4251.CVTPulleyCompoundStabilityAnalysis)

    @property
    def cylindrical_gear_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4256.CylindricalGearCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4256,
        )

        return self.__parent__._cast(_4256.CylindricalGearCompoundStabilityAnalysis)

    @property
    def cylindrical_planet_gear_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4259.CylindricalPlanetGearCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4259,
        )

        return self.__parent__._cast(
            _4259.CylindricalPlanetGearCompoundStabilityAnalysis
        )

    @property
    def face_gear_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4262.FaceGearCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4262,
        )

        return self.__parent__._cast(_4262.FaceGearCompoundStabilityAnalysis)

    @property
    def gear_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4267.GearCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4267,
        )

        return self.__parent__._cast(_4267.GearCompoundStabilityAnalysis)

    @property
    def hypoid_gear_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4271.HypoidGearCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4271,
        )

        return self.__parent__._cast(_4271.HypoidGearCompoundStabilityAnalysis)

    @property
    def klingelnberg_cyclo_palloid_conical_gear_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4275.KlingelnbergCycloPalloidConicalGearCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4275,
        )

        return self.__parent__._cast(
            _4275.KlingelnbergCycloPalloidConicalGearCompoundStabilityAnalysis
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4278.KlingelnbergCycloPalloidHypoidGearCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4278,
        )

        return self.__parent__._cast(
            _4278.KlingelnbergCycloPalloidHypoidGearCompoundStabilityAnalysis
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4281.KlingelnbergCycloPalloidSpiralBevelGearCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4281,
        )

        return self.__parent__._cast(
            _4281.KlingelnbergCycloPalloidSpiralBevelGearCompoundStabilityAnalysis
        )

    @property
    def mass_disc_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4284.MassDiscCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4284,
        )

        return self.__parent__._cast(_4284.MassDiscCompoundStabilityAnalysis)

    @property
    def measurement_component_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4285.MeasurementComponentCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4285,
        )

        return self.__parent__._cast(
            _4285.MeasurementComponentCompoundStabilityAnalysis
        )

    @property
    def oil_seal_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4289.OilSealCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4289,
        )

        return self.__parent__._cast(_4289.OilSealCompoundStabilityAnalysis)

    @property
    def part_to_part_shear_coupling_half_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4293.PartToPartShearCouplingHalfCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4293,
        )

        return self.__parent__._cast(
            _4293.PartToPartShearCouplingHalfCompoundStabilityAnalysis
        )

    @property
    def planet_carrier_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4296.PlanetCarrierCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4296,
        )

        return self.__parent__._cast(_4296.PlanetCarrierCompoundStabilityAnalysis)

    @property
    def point_load_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4297.PointLoadCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4297,
        )

        return self.__parent__._cast(_4297.PointLoadCompoundStabilityAnalysis)

    @property
    def power_load_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4298.PowerLoadCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4298,
        )

        return self.__parent__._cast(_4298.PowerLoadCompoundStabilityAnalysis)

    @property
    def pulley_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4299.PulleyCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4299,
        )

        return self.__parent__._cast(_4299.PulleyCompoundStabilityAnalysis)

    @property
    def ring_pins_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4300.RingPinsCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4300,
        )

        return self.__parent__._cast(_4300.RingPinsCompoundStabilityAnalysis)

    @property
    def rolling_ring_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4303.RollingRingCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4303,
        )

        return self.__parent__._cast(_4303.RollingRingCompoundStabilityAnalysis)

    @property
    def shaft_hub_connection_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4307.ShaftHubConnectionCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4307,
        )

        return self.__parent__._cast(_4307.ShaftHubConnectionCompoundStabilityAnalysis)

    @property
    def spiral_bevel_gear_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4310.SpiralBevelGearCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4310,
        )

        return self.__parent__._cast(_4310.SpiralBevelGearCompoundStabilityAnalysis)

    @property
    def spring_damper_half_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4315.SpringDamperHalfCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4315,
        )

        return self.__parent__._cast(_4315.SpringDamperHalfCompoundStabilityAnalysis)

    @property
    def straight_bevel_diff_gear_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4316.StraightBevelDiffGearCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4316,
        )

        return self.__parent__._cast(
            _4316.StraightBevelDiffGearCompoundStabilityAnalysis
        )

    @property
    def straight_bevel_gear_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4319.StraightBevelGearCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4319,
        )

        return self.__parent__._cast(_4319.StraightBevelGearCompoundStabilityAnalysis)

    @property
    def straight_bevel_planet_gear_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4322.StraightBevelPlanetGearCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4322,
        )

        return self.__parent__._cast(
            _4322.StraightBevelPlanetGearCompoundStabilityAnalysis
        )

    @property
    def straight_bevel_sun_gear_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4323.StraightBevelSunGearCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4323,
        )

        return self.__parent__._cast(
            _4323.StraightBevelSunGearCompoundStabilityAnalysis
        )

    @property
    def synchroniser_half_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4325.SynchroniserHalfCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4325,
        )

        return self.__parent__._cast(_4325.SynchroniserHalfCompoundStabilityAnalysis)

    @property
    def synchroniser_part_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4326.SynchroniserPartCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4326,
        )

        return self.__parent__._cast(_4326.SynchroniserPartCompoundStabilityAnalysis)

    @property
    def synchroniser_sleeve_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4327.SynchroniserSleeveCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4327,
        )

        return self.__parent__._cast(_4327.SynchroniserSleeveCompoundStabilityAnalysis)

    @property
    def torque_converter_pump_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4330.TorqueConverterPumpCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4330,
        )

        return self.__parent__._cast(_4330.TorqueConverterPumpCompoundStabilityAnalysis)

    @property
    def torque_converter_turbine_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4331.TorqueConverterTurbineCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4331,
        )

        return self.__parent__._cast(
            _4331.TorqueConverterTurbineCompoundStabilityAnalysis
        )

    @property
    def unbalanced_mass_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4332.UnbalancedMassCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4332,
        )

        return self.__parent__._cast(_4332.UnbalancedMassCompoundStabilityAnalysis)

    @property
    def virtual_component_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4333.VirtualComponentCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4333,
        )

        return self.__parent__._cast(_4333.VirtualComponentCompoundStabilityAnalysis)

    @property
    def worm_gear_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4334.WormGearCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4334,
        )

        return self.__parent__._cast(_4334.WormGearCompoundStabilityAnalysis)

    @property
    def zerol_bevel_gear_compound_stability_analysis(
        self: "CastSelf",
    ) -> "_4337.ZerolBevelGearCompoundStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses.compound import (
            _4337,
        )

        return self.__parent__._cast(_4337.ZerolBevelGearCompoundStabilityAnalysis)

    @property
    def mountable_component_compound_stability_analysis(
        self: "CastSelf",
    ) -> "MountableComponentCompoundStabilityAnalysis":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class MountableComponentCompoundStabilityAnalysis(
    _4234.ComponentCompoundStabilityAnalysis
):
    """MountableComponentCompoundStabilityAnalysis

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _MOUNTABLE_COMPONENT_COMPOUND_STABILITY_ANALYSIS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def component_analysis_cases(
        self: "Self",
    ) -> "List[_4154.MountableComponentStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.MountableComponentStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ComponentAnalysisCases")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def component_analysis_cases_ready(
        self: "Self",
    ) -> "List[_4154.MountableComponentStabilityAnalysis]":
        """List[mastapy.system_model.analyses_and_results.stability_analyses.MountableComponentStabilityAnalysis]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ComponentAnalysisCasesReady")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_MountableComponentCompoundStabilityAnalysis":
        """Cast to another type.

        Returns:
            _Cast_MountableComponentCompoundStabilityAnalysis
        """
        return _Cast_MountableComponentCompoundStabilityAnalysis(self)



"""PlaneVectorFieldData"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private import _7951
from mastapy._private._internal import conversion, utility

_ARRAY = python_net_import("System", "Array")
_PLANE_VECTOR_FIELD_DATA = python_net_import(
    "SMT.MastaAPI.Utility.Vectors", "PlaneVectorFieldData"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    Self = TypeVar("Self", bound="PlaneVectorFieldData")
    CastSelf = TypeVar(
        "CastSelf", bound="PlaneVectorFieldData._Cast_PlaneVectorFieldData"
    )


__docformat__ = "restructuredtext en"
__all__ = ("PlaneVectorFieldData",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_PlaneVectorFieldData:
    """Special nested class for casting PlaneVectorFieldData to subclasses."""

    __parent__: "PlaneVectorFieldData"

    @property
    def marshal_by_ref_object_permanent(
        self: "CastSelf",
    ) -> "_7951.MarshalByRefObjectPermanent":
        return self.__parent__._cast(_7951.MarshalByRefObjectPermanent)

    @property
    def plane_vector_field_data(self: "CastSelf") -> "PlaneVectorFieldData":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class PlaneVectorFieldData(_7951.MarshalByRefObjectPermanent):
    """PlaneVectorFieldData

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _PLANE_VECTOR_FIELD_DATA

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def titles(self: "Self") -> "List[str]":
        """List[str]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Titles")

        if temp is None:
            return None

        value = conversion.to_list_any(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def values(self: "Self") -> "List[List[float]]":
        """List[List[float]]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Values")

        if temp is None:
            return None

        value = conversion.pn_to_mp_list_float_2d(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_PlaneVectorFieldData":
        """Cast to another type.

        Returns:
            _Cast_PlaneVectorFieldData
        """
        return _Cast_PlaneVectorFieldData(self)



"""ModalContributionFilteringMethod"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal.python_net import python_net_import

_MODAL_CONTRIBUTION_FILTERING_METHOD = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.HarmonicAnalyses.Results",
    "ModalContributionFilteringMethod",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="ModalContributionFilteringMethod")
    CastSelf = TypeVar(
        "CastSelf",
        bound="ModalContributionFilteringMethod._Cast_ModalContributionFilteringMethod",
    )


__docformat__ = "restructuredtext en"
__all__ = ("ModalContributionFilteringMethod",)


class ModalContributionFilteringMethod(Enum):
    """ModalContributionFilteringMethod

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls) -> "Type":
        return _MODAL_CONTRIBUTION_FILTERING_METHOD

    NO_FILTERING = 0
    ABSOLUTE_AT_MODE_NATURAL_FREQUENCY = 1
    ABSOLUTE_AT_FIXED_FREQUENCY = 2
    INTEGRAL_OVER_FREQUENCY_RANGE = 3


def __enum_setattr(self: "Self", attr: str, value: "Any") -> None:
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: "Self", attr: str) -> None:
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


ModalContributionFilteringMethod.__setattr__ = __enum_setattr
ModalContributionFilteringMethod.__delattr__ = __enum_delattr



"""SpecialisedAssemblyAdvancedSystemDeflection"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, utility
from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
    _7446,
)

_SPECIALISED_ASSEMBLY_ADVANCED_SYSTEM_DEFLECTION = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.AdvancedSystemDeflections",
    "SpecialisedAssemblyAdvancedSystemDeflection",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2944, _2946, _2950
    from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
        _7455,
        _7459,
        _7462,
        _7467,
        _7469,
        _7470,
        _7475,
        _7480,
        _7483,
        _7487,
        _7490,
        _7493,
        _7499,
        _7506,
        _7508,
        _7511,
        _7515,
        _7519,
        _7522,
        _7525,
        _7530,
        _7533,
        _7534,
        _7538,
        _7546,
        _7555,
        _7556,
        _7561,
        _7564,
        _7567,
        _7571,
        _7580,
        _7583,
    )
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7943,
        _7946,
    )
    from mastapy._private.system_model.part_model import _2753

    Self = TypeVar("Self", bound="SpecialisedAssemblyAdvancedSystemDeflection")
    CastSelf = TypeVar(
        "CastSelf",
        bound="SpecialisedAssemblyAdvancedSystemDeflection._Cast_SpecialisedAssemblyAdvancedSystemDeflection",
    )


__docformat__ = "restructuredtext en"
__all__ = ("SpecialisedAssemblyAdvancedSystemDeflection",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_SpecialisedAssemblyAdvancedSystemDeflection:
    """Special nested class for casting SpecialisedAssemblyAdvancedSystemDeflection to subclasses."""

    __parent__: "SpecialisedAssemblyAdvancedSystemDeflection"

    @property
    def abstract_assembly_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7446.AbstractAssemblyAdvancedSystemDeflection":
        return self.__parent__._cast(_7446.AbstractAssemblyAdvancedSystemDeflection)

    @property
    def part_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7533.PartAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7533,
        )

        return self.__parent__._cast(_7533.PartAdvancedSystemDeflection)

    @property
    def part_static_load_analysis_case(
        self: "CastSelf",
    ) -> "_7946.PartStaticLoadAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7946,
        )

        return self.__parent__._cast(_7946.PartStaticLoadAnalysisCase)

    @property
    def part_analysis_case(self: "CastSelf") -> "_7943.PartAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7943,
        )

        return self.__parent__._cast(_7943.PartAnalysisCase)

    @property
    def part_analysis(self: "CastSelf") -> "_2950.PartAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2950

        return self.__parent__._cast(_2950.PartAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2946.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2946

        return self.__parent__._cast(_2946.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def agma_gleason_conical_gear_set_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7455.AGMAGleasonConicalGearSetAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7455,
        )

        return self.__parent__._cast(
            _7455.AGMAGleasonConicalGearSetAdvancedSystemDeflection
        )

    @property
    def belt_drive_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7459.BeltDriveAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7459,
        )

        return self.__parent__._cast(_7459.BeltDriveAdvancedSystemDeflection)

    @property
    def bevel_differential_gear_set_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7462.BevelDifferentialGearSetAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7462,
        )

        return self.__parent__._cast(
            _7462.BevelDifferentialGearSetAdvancedSystemDeflection
        )

    @property
    def bevel_gear_set_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7467.BevelGearSetAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7467,
        )

        return self.__parent__._cast(_7467.BevelGearSetAdvancedSystemDeflection)

    @property
    def bolted_joint_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7469.BoltedJointAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7469,
        )

        return self.__parent__._cast(_7469.BoltedJointAdvancedSystemDeflection)

    @property
    def clutch_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7470.ClutchAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7470,
        )

        return self.__parent__._cast(_7470.ClutchAdvancedSystemDeflection)

    @property
    def concept_coupling_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7475.ConceptCouplingAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7475,
        )

        return self.__parent__._cast(_7475.ConceptCouplingAdvancedSystemDeflection)

    @property
    def concept_gear_set_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7480.ConceptGearSetAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7480,
        )

        return self.__parent__._cast(_7480.ConceptGearSetAdvancedSystemDeflection)

    @property
    def conical_gear_set_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7483.ConicalGearSetAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7483,
        )

        return self.__parent__._cast(_7483.ConicalGearSetAdvancedSystemDeflection)

    @property
    def coupling_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7487.CouplingAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7487,
        )

        return self.__parent__._cast(_7487.CouplingAdvancedSystemDeflection)

    @property
    def cvt_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7490.CVTAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7490,
        )

        return self.__parent__._cast(_7490.CVTAdvancedSystemDeflection)

    @property
    def cycloidal_assembly_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7493.CycloidalAssemblyAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7493,
        )

        return self.__parent__._cast(_7493.CycloidalAssemblyAdvancedSystemDeflection)

    @property
    def cylindrical_gear_set_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7499.CylindricalGearSetAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7499,
        )

        return self.__parent__._cast(_7499.CylindricalGearSetAdvancedSystemDeflection)

    @property
    def face_gear_set_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7506.FaceGearSetAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7506,
        )

        return self.__parent__._cast(_7506.FaceGearSetAdvancedSystemDeflection)

    @property
    def flexible_pin_assembly_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7508.FlexiblePinAssemblyAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7508,
        )

        return self.__parent__._cast(_7508.FlexiblePinAssemblyAdvancedSystemDeflection)

    @property
    def gear_set_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7511.GearSetAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7511,
        )

        return self.__parent__._cast(_7511.GearSetAdvancedSystemDeflection)

    @property
    def hypoid_gear_set_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7515.HypoidGearSetAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7515,
        )

        return self.__parent__._cast(_7515.HypoidGearSetAdvancedSystemDeflection)

    @property
    def klingelnberg_cyclo_palloid_conical_gear_set_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7519.KlingelnbergCycloPalloidConicalGearSetAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7519,
        )

        return self.__parent__._cast(
            _7519.KlingelnbergCycloPalloidConicalGearSetAdvancedSystemDeflection
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_set_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7522.KlingelnbergCycloPalloidHypoidGearSetAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7522,
        )

        return self.__parent__._cast(
            _7522.KlingelnbergCycloPalloidHypoidGearSetAdvancedSystemDeflection
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_set_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7525.KlingelnbergCycloPalloidSpiralBevelGearSetAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7525,
        )

        return self.__parent__._cast(
            _7525.KlingelnbergCycloPalloidSpiralBevelGearSetAdvancedSystemDeflection
        )

    @property
    def microphone_array_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7530.MicrophoneArrayAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7530,
        )

        return self.__parent__._cast(_7530.MicrophoneArrayAdvancedSystemDeflection)

    @property
    def part_to_part_shear_coupling_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7534.PartToPartShearCouplingAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7534,
        )

        return self.__parent__._cast(
            _7534.PartToPartShearCouplingAdvancedSystemDeflection
        )

    @property
    def planetary_gear_set_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7538.PlanetaryGearSetAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7538,
        )

        return self.__parent__._cast(_7538.PlanetaryGearSetAdvancedSystemDeflection)

    @property
    def rolling_ring_assembly_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7546.RollingRingAssemblyAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7546,
        )

        return self.__parent__._cast(_7546.RollingRingAssemblyAdvancedSystemDeflection)

    @property
    def spiral_bevel_gear_set_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7555.SpiralBevelGearSetAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7555,
        )

        return self.__parent__._cast(_7555.SpiralBevelGearSetAdvancedSystemDeflection)

    @property
    def spring_damper_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7556.SpringDamperAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7556,
        )

        return self.__parent__._cast(_7556.SpringDamperAdvancedSystemDeflection)

    @property
    def straight_bevel_diff_gear_set_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7561.StraightBevelDiffGearSetAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7561,
        )

        return self.__parent__._cast(
            _7561.StraightBevelDiffGearSetAdvancedSystemDeflection
        )

    @property
    def straight_bevel_gear_set_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7564.StraightBevelGearSetAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7564,
        )

        return self.__parent__._cast(_7564.StraightBevelGearSetAdvancedSystemDeflection)

    @property
    def synchroniser_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7567.SynchroniserAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7567,
        )

        return self.__parent__._cast(_7567.SynchroniserAdvancedSystemDeflection)

    @property
    def torque_converter_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7571.TorqueConverterAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7571,
        )

        return self.__parent__._cast(_7571.TorqueConverterAdvancedSystemDeflection)

    @property
    def worm_gear_set_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7580.WormGearSetAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7580,
        )

        return self.__parent__._cast(_7580.WormGearSetAdvancedSystemDeflection)

    @property
    def zerol_bevel_gear_set_advanced_system_deflection(
        self: "CastSelf",
    ) -> "_7583.ZerolBevelGearSetAdvancedSystemDeflection":
        from mastapy._private.system_model.analyses_and_results.advanced_system_deflections import (
            _7583,
        )

        return self.__parent__._cast(_7583.ZerolBevelGearSetAdvancedSystemDeflection)

    @property
    def specialised_assembly_advanced_system_deflection(
        self: "CastSelf",
    ) -> "SpecialisedAssemblyAdvancedSystemDeflection":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class SpecialisedAssemblyAdvancedSystemDeflection(
    _7446.AbstractAssemblyAdvancedSystemDeflection
):
    """SpecialisedAssemblyAdvancedSystemDeflection

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _SPECIALISED_ASSEMBLY_ADVANCED_SYSTEM_DEFLECTION

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def assembly_design(self: "Self") -> "_2753.SpecialisedAssembly":
        """mastapy.system_model.part_model.SpecialisedAssembly

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AssemblyDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_SpecialisedAssemblyAdvancedSystemDeflection":
        """Cast to another type.

        Returns:
            _Cast_SpecialisedAssemblyAdvancedSystemDeflection
        """
        return _Cast_SpecialisedAssemblyAdvancedSystemDeflection(self)



"""LoadedBallElementChartReporter"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private._internal import (
    conversion,
    enum_with_selected_value_runtime,
    utility,
)
from mastapy._private._internal.implicit import enum_with_selected_value
from mastapy._private.bearings.bearing_results import _2203
from mastapy._private.utility.report import _1985

_LOADED_BALL_ELEMENT_CHART_REPORTER = python_net_import(
    "SMT.MastaAPI.Bearings.BearingResults", "LoadedBallElementChartReporter"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.utility.report import _1992, _1998, _1999, _2000

    Self = TypeVar("Self", bound="LoadedBallElementChartReporter")
    CastSelf = TypeVar(
        "CastSelf",
        bound="LoadedBallElementChartReporter._Cast_LoadedBallElementChartReporter",
    )


__docformat__ = "restructuredtext en"
__all__ = ("LoadedBallElementChartReporter",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_LoadedBallElementChartReporter:
    """Special nested class for casting LoadedBallElementChartReporter to subclasses."""

    __parent__: "LoadedBallElementChartReporter"

    @property
    def custom_report_chart(self: "CastSelf") -> "_1985.CustomReportChart":
        return self.__parent__._cast(_1985.CustomReportChart)

    @property
    def custom_report_multi_property_item(
        self: "CastSelf",
    ) -> "_1998.CustomReportMultiPropertyItem":
        pass

        from mastapy._private.utility.report import _1998

        return self.__parent__._cast(_1998.CustomReportMultiPropertyItem)

    @property
    def custom_report_multi_property_item_base(
        self: "CastSelf",
    ) -> "_1999.CustomReportMultiPropertyItemBase":
        from mastapy._private.utility.report import _1999

        return self.__parent__._cast(_1999.CustomReportMultiPropertyItemBase)

    @property
    def custom_report_nameable_item(
        self: "CastSelf",
    ) -> "_2000.CustomReportNameableItem":
        from mastapy._private.utility.report import _2000

        return self.__parent__._cast(_2000.CustomReportNameableItem)

    @property
    def custom_report_item(self: "CastSelf") -> "_1992.CustomReportItem":
        from mastapy._private.utility.report import _1992

        return self.__parent__._cast(_1992.CustomReportItem)

    @property
    def loaded_ball_element_chart_reporter(
        self: "CastSelf",
    ) -> "LoadedBallElementChartReporter":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class LoadedBallElementChartReporter(_1985.CustomReportChart):
    """LoadedBallElementChartReporter

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _LOADED_BALL_ELEMENT_CHART_REPORTER

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def element_to_plot(
        self: "Self",
    ) -> "enum_with_selected_value.EnumWithSelectedValue_LoadedBallElementPropertyType":
        """EnumWithSelectedValue[mastapy.bearings.bearing_results.LoadedBallElementPropertyType]"""
        temp = pythonnet_property_get(self.wrapped, "ElementToPlot")

        if temp is None:
            return None

        value = enum_with_selected_value.EnumWithSelectedValue_LoadedBallElementPropertyType.wrapped_type()
        return enum_with_selected_value_runtime.create(temp, value)

    @element_to_plot.setter
    @exception_bridge
    @enforce_parameter_types
    def element_to_plot(
        self: "Self", value: "_2203.LoadedBallElementPropertyType"
    ) -> None:
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = enum_with_selected_value.EnumWithSelectedValue_LoadedBallElementPropertyType.implicit_type()
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](value)
        pythonnet_property_set(self.wrapped, "ElementToPlot", value)

    @property
    def cast_to(self: "Self") -> "_Cast_LoadedBallElementChartReporter":
        """Cast to another type.

        Returns:
            _Cast_LoadedBallElementChartReporter
        """
        return _Cast_LoadedBallElementChartReporter(self)



"""CylindricalManufacturedGearMeshDutyCycle"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import python_net_import

from mastapy._private._internal import utility
from mastapy._private.gears.analysis import _1370

_CYLINDRICAL_MANUFACTURED_GEAR_MESH_DUTY_CYCLE = python_net_import(
    "SMT.MastaAPI.Gears.Manufacturing.Cylindrical",
    "CylindricalManufacturedGearMeshDutyCycle",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.analysis import _1362, _1368

    Self = TypeVar("Self", bound="CylindricalManufacturedGearMeshDutyCycle")
    CastSelf = TypeVar(
        "CastSelf",
        bound="CylindricalManufacturedGearMeshDutyCycle._Cast_CylindricalManufacturedGearMeshDutyCycle",
    )


__docformat__ = "restructuredtext en"
__all__ = ("CylindricalManufacturedGearMeshDutyCycle",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_CylindricalManufacturedGearMeshDutyCycle:
    """Special nested class for casting CylindricalManufacturedGearMeshDutyCycle to subclasses."""

    __parent__: "CylindricalManufacturedGearMeshDutyCycle"

    @property
    def gear_mesh_implementation_analysis_duty_cycle(
        self: "CastSelf",
    ) -> "_1370.GearMeshImplementationAnalysisDutyCycle":
        return self.__parent__._cast(_1370.GearMeshImplementationAnalysisDutyCycle)

    @property
    def gear_mesh_design_analysis(self: "CastSelf") -> "_1368.GearMeshDesignAnalysis":
        from mastapy._private.gears.analysis import _1368

        return self.__parent__._cast(_1368.GearMeshDesignAnalysis)

    @property
    def abstract_gear_mesh_analysis(
        self: "CastSelf",
    ) -> "_1362.AbstractGearMeshAnalysis":
        from mastapy._private.gears.analysis import _1362

        return self.__parent__._cast(_1362.AbstractGearMeshAnalysis)

    @property
    def cylindrical_manufactured_gear_mesh_duty_cycle(
        self: "CastSelf",
    ) -> "CylindricalManufacturedGearMeshDutyCycle":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class CylindricalManufacturedGearMeshDutyCycle(
    _1370.GearMeshImplementationAnalysisDutyCycle
):
    """CylindricalManufacturedGearMeshDutyCycle

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CYLINDRICAL_MANUFACTURED_GEAR_MESH_DUTY_CYCLE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_CylindricalManufacturedGearMeshDutyCycle":
        """Cast to another type.

        Returns:
            _Cast_CylindricalManufacturedGearMeshDutyCycle
        """
        return _Cast_CylindricalManufacturedGearMeshDutyCycle(self)
